Thread (4 messages) 4 messages, 3 authors, 2007-11-01

Re: [Bugme-new] [Bug 9270] New: sunhme requires lower MTU to handle 802.1q frames

From: Andrew Morton <akpm@linux-foundation.org>
Date: 2007-11-01 19:13:16

On Wed, 31 Oct 2007 16:35:57 -0700 (PDT)
David Miller [off-list ref] wrote:
quoted hunk ↗ jump to hunk
From: Andrew Morton <akpm@linux-foundation.org>
Date: Wed, 31 Oct 2007 15:43:01 -0700
quoted
quoted
sunhme requires lower MTU to handle 802.1q frames - even though the PCI
driver supported VLAN tagging, you cannot do full MTU @ 1500 because the
driver doesn't set the card to transfer more the extra bytes for a 802.1q
frame at 1500 MTU.
It supports VLAN tagging by accident, the NETIF_F_VLAN_CHALLENGED
flag should be set both in the PCI and non-PCI cases.

Jeff, please apply, thanks:

[SUNHME]: Fix missing NETIF_F_VLAN_CHALLENGED on PCI happy meals.

No HME parts can do VLANs correctly.

Signed-off-by: David S. Miller <davem@davemloft.net>
diff --git a/drivers/net/sunhme.c b/drivers/net/sunhme.c
index 120c8af..c20a3bd 100644
--- a/drivers/net/sunhme.c
+++ b/drivers/net/sunhme.c
@@ -3143,8 +3143,8 @@ static int __devinit happy_meal_pci_probe(struct pci_dev *pdev,
 	dev->irq = pdev->irq;
 	dev->dma = 0;
 
-	/* Happy Meal can do it all... */
-	dev->features |= NETIF_F_SG | NETIF_F_HW_CSUM;
+	/* Happy Meal can do it all... except VLAN. */
+	dev->features |= NETIF_F_SG | NETIF_F_HW_CSUM | NETIF_F_VLAN_CHALLENGED;
 
 #if defined(CONFIG_SBUS) && defined(CONFIG_PCI)
 	/* Hook up PCI register/dma accessors. */
I forgot to add my standard "please reply via emailed reply-to-all, not via
the bugzilla web interface", so Chris has gone and attempted to communicate
with us via the bugzilla UI (sigh).

He asked

"Even though it appears to work after I bumped the BMAC_TXMAX / BMAC_RXMAX?"

Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help